*******************************************************************************
ClayBullet object creator and JSON read & write
*******************************************************************************

:download:`create_bullets_read_write_json.gh <./create_bullets_read_write_json.gh>`.

.. note::
  Requires ``compas_rcf`` installed and available from inside Rhino. Follow the
  installation steps in the :doc:`../getting_started`.

Includes
--------

-  Components to create :class:`compas_rcf.fabrication.ClayBullet` objects as
   well as reading and writing them to a json file
